Bitboard

Struct Bitboard 

pub struct Bitboard(pub u64);

Tuple Fields

0: u64

Implementations

Source

impl Bitboard

Bitboard Construction API.

pub const fn from_file(file: File) -> Bitboard

pub const fn from_rank(rank: Rank) -> Bitboard

pub const fn from_square(square: Square) -> Bitboard

pub const fn from_squares<const N: usize>(squares: [Square; N]) -> Bitboard

Source

impl Bitboard

Bitboard Set API.

pub const fn append(&mut self, squares: Bitboard)

Appends squares.

pub const fn clear(&mut self)

pub const fn contains(self, square: Square) -> bool

pub const fn difference(self, squares: Bitboard) -> Bitboard

pub const fn eq(self, other: Self) -> bool

pub const fn first(self) -> Option<Square>

pub const fn insert(&mut self, square: Square) -> bool

pub const fn intersection(self, squares: Bitboard) -> Bitboard

pub const fn is_disjoint(self, other: Bitboard) -> bool

pub const fn is_empty(self) -> bool

pub const fn is_subset(self, other: Bitboard) -> bool

pub const fn is_superset(self, other: Bitboard) -> bool

pub const fn iter(self) -> IntoIter

pub const fn last(self) -> Option<Square>

pub const fn len(self) -> usize

pub const fn pop_first(&mut self) -> Option<Square>

pub const fn pop_last(&mut self) -> Option<Square>

pub const fn remove(&mut self, square: Square) -> bool

pub const fn symmetric_difference(self, squares: Bitboard) -> Bitboard

pub const fn union(self, squares: Bitboard) -> Bitboard

Source

impl Bitboard

Set extensions

pub const fn more_than_one(self) -> bool

pub const fn next_subset(self, set: Bitboard) -> Bitboard

Returns the next subset of self after set, wrapping back to empty.

set is expected to be a subset of self.

pub const fn set(&mut self, square: Square, set: bool)

pub const fn with(self, square: Square) -> Bitboard

pub const fn without_first(self) -> Bitboard

Source

impl Bitboard

Bitboard Geometry API.

pub const fn checked_shift(self, direction: Direction) -> Bitboard

pub const fn flip_anti_diagonal(self) -> Bitboard

Mirror at h1-a8 diagonal

pub const fn flip_diagonal(self) -> Bitboard

Mirror at a1-h8 diagonal

pub const fn flip_horizontal(self) -> Bitboard

pub const fn flip_vertical(self) -> Bitboard

pub const fn rotate_180(self) -> Bitboard

pub const fn rotate_270(self) -> Bitboard

pub const fn rotate_90(self) -> Bitboard

pub const fn without_a_file(self) -> Bitboard

pub const fn without_ab_files(self) -> Bitboard

pub const fn without_gh_files(self) -> Bitboard

pub const fn without_h_file(self) -> Bitboard

Source

impl Bitboard

Constants