pub struct Bitboard(pub u64);Tuple Fields
0: u64Implementations
Sourceimpl Bitboard
Bitboard Set API.
impl Bitboard
Bitboard Set API.
pub const fn clear(&mut self)
pub const fn contains(self, square: Square) -> bool
pub const fn difference(self, squares: Bitboard) -> Bitboard
pub const fn eq(self, other: Self) -> bool
pub const fn first(self) -> Option<Square>
pub const fn insert(&mut self, square: Square) -> bool
pub const fn intersection(self, squares: Bitboard) -> Bitboard
pub const fn is_disjoint(self, other: Bitboard) -> bool
pub const fn is_empty(self) -> bool
pub const fn is_subset(self, other: Bitboard) -> bool
pub const fn is_superset(self, other: Bitboard) -> bool
pub const fn iter(self) -> IntoIter
pub const fn last(self) -> Option<Square>
pub const fn len(self) -> usize
pub const fn pop_first(&mut self) -> Option<Square>
pub const fn pop_last(&mut self) -> Option<Square>
pub const fn remove(&mut self, square: Square) -> bool
pub const fn symmetric_difference(self, squares: Bitboard) -> Bitboard
pub const fn union(self, squares: Bitboard) -> Bitboard
Sourceimpl Bitboard
Set extensions
impl Bitboard
Set extensions
pub const fn more_than_one(self) -> bool
Sourcepub const fn next_subset(self, set: Bitboard) -> Bitboard
pub const fn next_subset(self, set: Bitboard) -> Bitboard
Returns the next subset of self after set, wrapping back to empty.
set is expected to be a subset of self.
pub const fn set(&mut self, square: Square, set: bool)
pub const fn with(self, square: Square) -> Bitboard
pub const fn without_first(self) -> Bitboard
Sourceimpl Bitboard
Bitboard Geometry API.
impl Bitboard
Bitboard Geometry API.
pub const fn checked_shift(self, direction: Direction) -> Bitboard
Sourcepub const fn flip_anti_diagonal(self) -> Bitboard
pub const fn flip_anti_diagonal(self) -> Bitboard
Mirror at h1-a8 diagonal
Sourcepub const fn flip_diagonal(self) -> Bitboard
pub const fn flip_diagonal(self) -> Bitboard
Mirror at a1-h8 diagonal
pub const fn flip_horizontal(self) -> Bitboard
pub const fn flip_vertical(self) -> Bitboard
pub const fn rotate_180(self) -> Bitboard
pub const fn rotate_270(self) -> Bitboard
pub const fn rotate_90(self) -> Bitboard
pub const fn without_a_file(self) -> Bitboard
pub const fn without_ab_files(self) -> Bitboard
pub const fn without_gh_files(self) -> Bitboard
pub const fn without_h_file(self) -> Bitboard
Sourceimpl Bitboard
Constants
impl Bitboard
Constants
pub const ANTIDIAGONAL: Bitboard
pub const BACKRANKS: Bitboard
pub const BLACK: Bitboard
pub const CENTER: Bitboard
pub const CORNERS: Bitboard
pub const DIAGONAL: Bitboard
pub const EAST: Bitboard
pub const EMPTY: Bitboard
pub const FILE_A: Bitboard
pub const FULL: Bitboard
pub const FULL_RAYS: [[Bitboard; 64]; 64]
pub const NORTH: Bitboard
pub const SOUTH: Bitboard
pub const WEST: Bitboard
pub const WHITE: Bitboard